/*
    *
    * This file is a part of CoreInfo.
    * A file information viewer for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 2 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/


#ifndef COREINFO_H
#define COREINFO_H

#include <QWidget>
#include <QDir>
#include <QTreeWidget>

#include <ZenLib/Ztring.h>
#include <ZenLib/ZtringListList.h>
#include <cprime/settingsmanage.h>

#include "Core.h"


using namespace ZenLib;

#define wstring2QString(_DATA) \
    QString::fromUtf8(Ztring(_DATA).To_UTF8().c_str())
#define QString2wstring(_DATA) \
    Ztring().From_UTF8(_DATA.toUtf8())

namespace Ui {
    class coreinfo;
}

class coreinfo : public QWidget {
    Q_OBJECT
public:
    explicit coreinfo(QWidget *parent = nullptr);
    ~coreinfo();

    void openFiles(QStringList fileNames);
    void refreshDisplay();
    QDir getCommonDir(Core *C);

private slots:
    void openFileDialog();

private:
    Ui::coreinfo *ui;
    settingsManage *sm = settingsManage::initialize();
    bool sideView, touch;
    int sideViewSize;

    Core *C;
    QTreeWidget *showTreeView(bool completeDisplay);
    QString shortName(QDir d, QString name);

    void startSetup();
    void loadSettings();
};

#endif // COREINFO_H
